==> zanshin-0.4.1_p20170701.tar.xz: zanshin-0.4.1_p20170701/tests/testlib/akonadifakejobs.h <==
/* This file is part of Zanshin

   Copyright 2014 Kevin Ottens <ervin@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
   USA.
*/

#ifndef TESTLIB_AKONADIFAKEJOBS_H
#define TESTLIB_AKONADIFAKEJOBS_H

#include "fakejob.h"
#include "akonadi/akonadicollectionfetchjobinterface.h"
#include "akonadi/akonadiitemfetchjobinterface.h"
#include "akonadi/akonaditagfetchjobinterface.h"

namespace Testlib {

// cppcheck seems to get confused by the "using" in this class
// cppcheck-suppress noConstructor
class AkonadiFakeCollectionFetchJob : public FakeJob, public Akonadi::CollectionFetchJobInterface
{
    Q_OBJECT
public:
    using FakeJob::FakeJob;

    void setCollections(const Akonadi::Collection::List &collections);
    Akonadi::Collection::List collections() const Q_DECL_OVERRIDE;

    QString resource() const;
    void setResource(const QString &resource) Q_DECL_OVERRIDE;

private:
    Akonadi::Collection::List m_collections;
    QString m_resource;
};

class AkonadiFakeItemFetchJob : public FakeJob, public Akonadi::ItemFetchJobInterface
{
    Q_OBJECT
public:
    using FakeJob::FakeJob;

    void setItems(const Akonadi::Item::List &items);
    Akonadi::Item::List items() const Q_DECL_OVERRIDE;

    Akonadi::Collection collection() const;
    void setCollection(const Akonadi::Collection &collection) Q_DECL_OVERRIDE;

private:
    Akonadi::Item::List m_items;
    Akonadi::Collection m_collection;
};

class AkonadiFakeTagFetchJob : public FakeJob, public Akonadi::TagFetchJobInterface
{
    Q_OBJECT
public:
    using FakeJob::FakeJob;

    void setTags(const Akonadi::Tag::List &tags);
    Akonadi::Tag::List tags() const Q_DECL_OVERRIDE;

private:
    Akonadi::Tag::List m_tags;
};

}

#endif // TESTLIB_AKONADIFAKEJOBS_H

==> zanshin_0.5.71.orig.tar.xz: zanshin-0.5.71/tests/testlib/akonadifakejobs.h <==
/* This file is part of Zanshin

   Copyright 2014 Kevin Ottens <ervin@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
   USA.
*/

#ifndef TESTLIB_AKONADIFAKEJOBS_H
#define TESTLIB_AKONADIFAKEJOBS_H

#include "fakejob.h"
#include "akonadi/akonadicollectionfetchjobinterface.h"
#include "akonadi/akonadiitemfetchjobinterface.h"

namespace Testlib {

// cppcheck seems to get confused by the "using" in this class
// cppcheck-suppress noConstructor
class AkonadiFakeCollectionFetchJob : public FakeJob, public Akonadi::CollectionFetchJobInterface
{
    Q_OBJECT
public:
    using FakeJob::FakeJob;

    void setCollections(const Akonadi::Collection::List &collections);
    Akonadi::Collection::List collections() const override;

    QString resource() const;
    void setResource(const QString &resource) override;

private:
    Akonadi::Collection::List m_collections;
    QString m_resource;
};

class AkonadiFakeItemFetchJob : public FakeJob, public Akonadi::ItemFetchJobInterface
{
    Q_OBJECT
public:
    using FakeJob::FakeJob;

    void setItems(const Akonadi::Item::List &items);
    Akonadi::Item::List items() const override;

    Akonadi::Collection collection() const;
    void setCollection(const Akonadi::Collection &collection) override;

private:
    Akonadi::Item::List m_items;
    Akonadi::Collection m_collection;
};

}

#endif // TESTLIB_AKONADIFAKEJOBS_H
